############################################
MKS Instruments 937B Vacuum Gauge Controller
############################################

.. autoclass:: pymeasure.instruments.mksinst.mks937b.MKS937B
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.mksinst.mks937b.IonGaugeAndPressureChannel
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.mksinst.mks937b.PressureChannel
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.mksinst.mks937b.Relay
    :members:
    :show-inheritance:
